# Changelog

## [7.1.0](https://github.com/VersesTech/gpil/compare/pyvfg-v7.0.2...pyvfg-v7.1.0) (2025-05-13)


### Features

* GPIL-595 Upgrade `pymdp` to latest `master` ([#333](https://github.com/VersesTech/gpil/issues/333)) ([bfceba4](https://github.com/VersesTech/gpil/commit/bfceba4c08e1d855197215cee7297e3a68853851))

## [7.0.2](https://github.com/VersesTech/gpil/compare/pyvfg-v7.0.1...pyvfg-v7.0.2) (2025-05-09)


### Bug Fixes

* GPIL-624 duplicate vars error ([#336](https://github.com/VersesTech/gpil/issues/336)) ([7e4b2cd](https://github.com/VersesTech/gpil/commit/7e4b2cd5974c872b1674ebc92ab2ea50b50119bf))

## [7.0.1](https://github.com/VersesTech/gpil/compare/pyvfg-v7.0.0...pyvfg-v7.0.1) (2025-05-08)


### Bug Fixes

* GPIL-620 handle an empty metadata object during learning ([#334](https://github.com/VersesTech/gpil/issues/334)) ([223d163](https://github.com/VersesTech/gpil/commit/223d1630bae9db92f4dd664efaeb2cade688a1c7))

## [7.0.0](https://github.com/VersesTech/gpil/compare/pyvfg-v6.3.0...pyvfg-v7.0.0) (2025-05-01)


### ⚠ BREAKING CHANGES

* GPIL-511 remove deprecated methods from pyvfg: `set_graph` and `get_graph`. ([#282](https://github.com/VersesTech/gpil/issues/282))

### Features

* GPIL-511 remove deprecated methods from pyvfg: `set_graph` and `get_graph`. ([#282](https://github.com/VersesTech/gpil/issues/282)) ([07593d8](https://github.com/VersesTech/gpil/commit/07593d8d25bb4477680f7151f770c6b2d9313061))

## [6.3.0](https://github.com/VersesTech/gpil/compare/pyvfg-v6.2.4...pyvfg-v6.3.0) (2025-05-01)


### Features

* GPIL-615 error patch for multiple factors on one variable ([#327](https://github.com/VersesTech/gpil/issues/327)) ([bfdcb2b](https://github.com/VersesTech/gpil/commit/bfdcb2b3adcde345a23d1b842aae78acfa63e3ff))

## [6.2.4](https://github.com/VersesTech/gpil/compare/pyvfg-v6.2.3...pyvfg-v6.2.4) (2025-04-29)


### Bug Fixes

* GPIL-611 fix latent routes ([#323](https://github.com/VersesTech/gpil/issues/323)) ([6221c4b](https://github.com/VersesTech/gpil/commit/6221c4bd2f708a4184bdb2f29b7a7bc378cf66a2))
* GPIL-615 raise validation error on multiple factors for one variable ([#325](https://github.com/VersesTech/gpil/issues/325)) ([643a4a6](https://github.com/VersesTech/gpil/commit/643a4a670285beaf7a7ee7c44e8827b8c156334a))

## [6.2.3](https://github.com/VersesTech/gpil/compare/pyvfg-v6.2.2...pyvfg-v6.2.3) (2025-04-26)


### Bug Fixes

* GPIL-538 rm python version, downgrade scipy ([#320](https://github.com/VersesTech/gpil/issues/320)) ([e524d3d](https://github.com/VersesTech/gpil/commit/e524d3d324064757182a93e88ec1d7607f7f34b1))

## [6.2.2](https://github.com/VersesTech/gpil/compare/pyvfg-v6.2.1...pyvfg-v6.2.2) (2025-04-25)


### Bug Fixes

* GPIL-0 removed pgmax dependency by supplying a one-line function ([#318](https://github.com/VersesTech/gpil/issues/318)) ([074cbe1](https://github.com/VersesTech/gpil/commit/074cbe166c8cc45105cd522bb2647ecc11d20193))

## [6.2.1](https://github.com/VersesTech/gpil/compare/pyvfg-v6.2.0...pyvfg-v6.2.1) (2025-04-22)


### Bug Fixes

* GPIL-572 pyvfg requires-python 3.11 ([#313](https://github.com/VersesTech/gpil/issues/313)) ([683717c](https://github.com/VersesTech/gpil/commit/683717c1207a301a7d78f60fcfa132703c70f8a1))

## [6.2.0](https://github.com/VersesTech/gpil/compare/pyvfg-v6.1.0...pyvfg-v6.2.0) (2025-04-17)


### Features

* GPIL-493 Added a few models and a dataset ([#311](https://github.com/VersesTech/gpil/issues/311)) ([ad11707](https://github.com/VersesTech/gpil/commit/ad117075ce2f1944ebe4deb8d6599d61e4ac80eb))

## [6.1.0](https://github.com/VersesTech/gpil/compare/pyvfg-v6.0.1...pyvfg-v6.1.0) (2025-04-15)


### Features

* GPIL-447 E-M integration ([#312](https://github.com/VersesTech/gpil/issues/312)) ([e6a0b6d](https://github.com/VersesTech/gpil/commit/e6a0b6d5faa905707979acf82ec411e18eb24b1b))

## [6.0.1](https://github.com/VersesTech/gpil/compare/pyvfg-v6.0.0...pyvfg-v6.0.1) (2025-03-31)


### Documentation

* GPIL-534 improve documentation for VFGs ([#300](https://github.com/VersesTech/gpil/issues/300)) ([76540f5](https://github.com/VersesTech/gpil/commit/76540f5882efb897c901e1063b207d1e95ce04bb))

## [6.0.0](https://github.com/VersesTech/gpil/compare/pyvfg-v5.0.0...pyvfg-v6.0.0) (2025-03-25)


### ⚠ BREAKING CHANGES

* GPIL-517 validate numeric values ([#291](https://github.com/VersesTech/gpil/issues/291))

### Features

* GPIL-517 validate numeric values ([#291](https://github.com/VersesTech/gpil/issues/291)) ([6267184](https://github.com/VersesTech/gpil/commit/6267184c93b2966ec0ae3248efac60eb685b7661))

## [5.0.0](https://github.com/VersesTech/gpil/compare/pyvfg-v4.1.0...pyvfg-v5.0.0) (2025-03-21)


### ⚠ BREAKING CHANGES

* GPIL-401 VFG 0.5.0 (rebased) ([#288](https://github.com/VersesTech/gpil/issues/288))

### Features

* GPIL-401 VFG 0.5.0 (rebased) ([#288](https://github.com/VersesTech/gpil/issues/288)) ([f9f5476](https://github.com/VersesTech/gpil/commit/f9f5476e4f23604d71f9182e04e38a652cfc22e7))

## [4.1.0](https://github.com/VersesTech/gpil/compare/pyvfg-v4.0.0...pyvfg-v4.1.0) (2025-03-21)


### Features

* GPIL-409 MVP of MAP ([#281](https://github.com/VersesTech/gpil/issues/281)) ([458f1ab](https://github.com/VersesTech/gpil/commit/458f1abf56636b4f2c54c303e68cb674ef1cf9ab))

## [4.0.0](https://github.com/VersesTech/gpil/compare/pyvfg-v3.3.1...pyvfg-v4.0.0) (2025-03-21)


### ⚠ BREAKING CHANGES

* GPIL-491 learning overhaul; continuous learning by default ([#278](https://github.com/VersesTech/gpil/issues/278))

### Bug Fixes

* GPIL-491 learning overhaul; continuous learning by default ([#278](https://github.com/VersesTech/gpil/issues/278)) ([144af75](https://github.com/VersesTech/gpil/commit/144af7548b9652fdfa532bb056020d6bb9c38564))

## [3.3.1](https://github.com/VersesTech/gpil/compare/pyvfg-v3.3.0...pyvfg-v3.3.1) (2025-03-07)


### Bug Fixes

* GPIL-0 Typo correction ([#276](https://github.com/VersesTech/gpil/issues/276)) ([1def65e](https://github.com/VersesTech/gpil/commit/1def65e265bbaabe013766e4432c07e071e512ff))

## [3.3.0](https://github.com/VersesTech/gpil/compare/pyvfg-v3.2.0...pyvfg-v3.3.0) (2025-03-06)


### Features

* GPIL-343 rebase from SSoT; fixed latent var learning; optimized; new tests ([#259](https://github.com/VersesTech/gpil/issues/259)) ([851130f](https://github.com/VersesTech/gpil/commit/851130f317130e9ae6ad22bd3752fa4515e0f51b))


### Bug Fixes

* GPIL-0 pyvfg now lists all of its pyproject.toml dependencies ([#272](https://github.com/VersesTech/gpil/issues/272)) ([b29313a](https://github.com/VersesTech/gpil/commit/b29313af245ede45429205492e67b5e6030a0173))
* vfg_upgrade should convert a 030 vfg to 040 ([851130f](https://github.com/VersesTech/gpil/commit/851130f317130e9ae6ad22bd3752fa4515e0f51b))

## [3.2.0](https://github.com/VersesTech/gpil/compare/pyvfg-v3.1.2...pyvfg-v3.2.0) (2025-03-04)


### Features

* GPIL-382 Additional BDD test for validation ([#268](https://github.com/VersesTech/gpil/issues/268)) ([7cccead](https://github.com/VersesTech/gpil/commit/7ccceadc341e38c2499be031c5d8782670cc168b))

## [3.1.2](https://github.com/VersesTech/gpil/compare/pyvfg-v3.1.1...pyvfg-v3.1.2) (2025-03-04)


### Bug Fixes

* GPIL-382 vfg_upgrade should convert the version of a 030 vfg to 040 ([#267](https://github.com/VersesTech/gpil/issues/267)) ([d2bb242](https://github.com/VersesTech/gpil/commit/d2bb242208a2d67cb9aa64b301287c7b1dec4c49))
* vfg_upgrade should convert a 030 vfg to 040 ([d2bb242](https://github.com/VersesTech/gpil/commit/d2bb242208a2d67cb9aa64b301287c7b1dec4c49))

## [3.1.1](https://github.com/VersesTech/gpil/compare/pyvfg-v3.1.0...pyvfg-v3.1.1) (2025-03-03)


### Bug Fixes

* GPIL-382 the Factor class failed to generate schema ([#265](https://github.com/VersesTech/gpil/issues/265)) ([effaa53](https://github.com/VersesTech/gpil/commit/effaa5302c37bb8dedbfb15631d4d88b5c0efaeb))

## [3.1.0](https://github.com/VersesTech/gpil/compare/pyvfg-v3.0.3...pyvfg-v3.1.0) (2025-03-01)


### Features

* GPIL-328 extended, model-specific validation with optional correction + VFG performance improvements ([#260](https://github.com/VersesTech/gpil/issues/260)) ([7264603](https://github.com/VersesTech/gpil/commit/7264603e2414b62ba2450fdba7fc7af4bde2a34f))

## [3.0.3](https://github.com/VersesTech/gpil/compare/pyvfg-v3.0.2...pyvfg-v3.0.3) (2025-02-13)


### Bug Fixes

* copied validation tests from gpil-pipeline to ensure validate_graph() functions identically to previously. ([e64fbb7](https://github.com/VersesTech/gpil/commit/e64fbb77cd147529c2643f439127e9c5027ee35e))
* GPIL-0 validation should fail the same items that gpil-pipeline does ([#250](https://github.com/VersesTech/gpil/issues/250)) ([e64fbb7](https://github.com/VersesTech/gpil/commit/e64fbb77cd147529c2643f439127e9c5027ee35e))

## [3.0.2](https://github.com/VersesTech/gpil/compare/pyvfg-v3.0.1...pyvfg-v3.0.2) (2025-02-11)


### Bug Fixes

* GPIL-337 fixes for compatibility with shipped library ([#248](https://github.com/VersesTech/gpil/issues/248)) ([2f95d9c](https://github.com/VersesTech/gpil/commit/2f95d9c72c562ad9d91b7cb5d05aa79bc1520d0c))

## [3.0.1](https://github.com/VersesTech/gpil/compare/pyvfg-v3.0.0...pyvfg-v3.0.1) (2025-02-07)


### Bug Fixes

* GPIL-0 vfg_from_json needs to accept string or dict ([#245](https://github.com/VersesTech/gpil/issues/245)) ([7bed585](https://github.com/VersesTech/gpil/commit/7bed5858c3e78fbd9813c55e5dabdd1dacba2378))

## [3.0.0](https://github.com/VersesTech/gpil/compare/pyvfg-v2.1.3...pyvfg-v3.0.0) (2025-02-07)


### ⚠ BREAKING CHANGES

* GPIL-337 POMDP online learning ([#242](https://github.com/VersesTech/gpil/issues/242))

### Features

* GPIL-337 POMDP online learning ([#242](https://github.com/VersesTech/gpil/issues/242)) ([5728a81](https://github.com/VersesTech/gpil/commit/5728a81c6cc1e46f6f834c3667a5a75b89c18ceb))

## [2.1.3](https://github.com/VersesTech/gpil/compare/pyvfg-v2.1.2...pyvfg-v2.1.3) (2025-02-07)


### Bug Fixes

* GPIL-0 ValidationError should be an Exception ([#243](https://github.com/VersesTech/gpil/issues/243)) ([f3f4f86](https://github.com/VersesTech/gpil/commit/f3f4f86ab066f713d1a343c2a8e2b8b5874fa3de))

## [2.1.2](https://github.com/VersesTech/gpil/compare/pyvfg-v2.1.1...pyvfg-v2.1.2) (2025-02-06)


### Bug Fixes

* trigger new release ([dbd2ab1](https://github.com/VersesTech/gpil/commit/dbd2ab1131ebcb18687a21da990a315487f362f7))
